Container Name
  An arbitrary human-readable name.
Image
  Name or ID of container image.
Image Driver
  The image driver to use to pull container image.
  - Docker Hub: Pull the image from Docker Hub.
  - Glance: Pull the image from Glance.
Image Pull Policy
  The policy which determines if the image should be pulled prior to starting the container.
  - If not present: only pull the image if it does not already exist on the node.
  - Always: Always pull the image from repository.
  - Never: never pull the image.
Command
  Command sent to the container.